@@ -5,6 +5,7 @@ import re, math
 from collections import defaultdict
 import numpy
 import scipy
+import pandas as pd
 
 import cobra
 from cobra import Metabolite, Reaction, Gene
@@ -55,8 +56,6 @@ class model(cobra.Model):
                 reac.id += sf
             for met in sf_model.metabolites:
                 met.id += sf
-                if isinstance(met.compartment, str): 
-                    met.compartment += sf
             sf_model.repair()
             big_model.MergeWithModel(sf_model)
         return big_model
@@ -323,7 +322,6 @@ class model(cobra.Model):
         else:
             metabolite = Metabolite(id=met, formula=formula, name=name,
                                 charge=charge,compartment=compartment)
-            self.add_metabolites([metabolite])
 
     def DelMetabolite(self, met, destructive=False, method='substractive'):
         """ method = 'subtractive'|'destructive' """
@@ -542,6 +540,73 @@ class model(cobra.Model):
             for elm in input_dict:
                 result[elm.id] = elm
             return result
+    ## SCAN FUNCTIONS ##################################################################
+    def ScanFBA(self, range_list, rxn_constrained, obj_direct, obj_dict, save_as=None):
+        """
+        range_list: list of values the constraint is scanned over, e.g. [0.1, 0.2, 0.3, 0.4]
+        rxn_constrained: name of reaction being constrained e.g.'CO2_tx1'
+        obj_direct: direction of the objective function, either "Max" or "Min"
+        obj_dict: dictionary of objective function, e.g. {'Photon_tx1':1,'Photon_tx2':1}
+        save_as: path to csv file, e.g. "/home/scobra/FBA_results.csv"
+
+        return value: a pandas dataframe containing the output data of the scan
+        """
+
+        df = pd.DataFrame(self.Reactions(), columns=["Reactions"])
+
+        for i in range_list:
+            self.SetConstraints({rxn_constrained:(i,i)})
+            self.SetObjDirec(obj_direct)
+            self.SetObjective(obj_dict)
+            try:
+                self.MinFluxSolve()
+            except Exception as e:
+                print("Error in parameter: " + str(i))
+                continue
+            sol=self.GetSol(AsMtx=True)
+            dic = {"Reactions": sol.index, ("Flux" + str(i)): list(sol[sol.columns[0]])}
+            flux_df = pd.DataFrame(dic)
+
+            df = pd.merge(df, flux_df, on=["Reactions"], how="outer")
+
+        if save_as:
+            df.to_csv(save_as)
+
+        return(df)
+
+    def ScanFVA(self, range_list, rxn_constrained, obj_direct, obj_dict, save_as=None):
+        """
+        range_list: list of values the constraint is scanned over, e.g. [0.1, 0.2, 0.3, 0.4]
+        rxn_constrained: name of reaction being constrained e.g.'CO2_tx1'
+        obj_direct: direction of the objective function, either "Max" or "Min"
+        obj_dict: dictionary of objective function, e.g. {'Photon_tx1':1,'Photon_tx2':1}
+        save_as: path to csv file, e.g. "/home/scobra/FBA_results.csv"
+
+        return value: a pandas dataframe containing the output data of the scan
+        """
+        
+        df = pd.DataFrame(self.Reactions(), columns=["Reactions"])
+
+        for i in range_list:
+            self.SetConstraints({rxn_constrained:(i,i)})
+            self.SetObjDirec(obj_direct)
+            self.SetObjective(obj_dict)
+            try:
+                sol=self.FVA(cobra=True)
+            except Exception as e:
+                print("Error in parameter: " + str(i))
+                continue
+
+            dic = {"Reactions": sol.keys(),
+                    ("Flux" + str(i)+"Value1"): [x[0] for x in sol.values()],
+                    ("Flux" + str(i)+"Value2"): [x[1] for x in sol.values()]}
+            flux_df = pd.DataFrame(dic)
+            df = pd.merge(df, flux_df, on=["Reactions"], how="outer")
+
+        if save_as:
+            df.to_csv(save_as)
+
+        return(df)
 
     @property
     def ReactionsToGenesAssociations(self):
